<?php

declare(strict_types=1);

namespace Tricks\NovaTools\Nova\Fields;

use Illuminate\Database\Schema\Builder;
use Laravel\Nova\Fields\Text;

final class MetaDescription extends Text
{
    public $helpText = 'Wird auf der Website als Hauptüberschrift angezeigt und als Titel in der Browser-Registerkarte verwendet.';

    public function __construct(
        string $name = 'Überschrift',
        string $attribute = 'title'
    ) {
        parent::__construct($name, $attribute);

        $this->rules = [
            'required',
            'max:'.Builder::$defaultStringLength,
        ];

        /** @phpstan-ignore argument.type */
        $this->maxlength(Builder::$defaultStringLength, true);
    }
}
