<?php

declare(strict_types=1);

namespace Tricks\NovaTools\Nova\Fields;

use Laravel\Nova\Fields\Text;

final class ImageAlt extends Text
{
    public function __construct(string $name, ?string $attribute = null)
    {
        parent::__construct($name, $attribute);

        $this->hideFromIndex()
            ->help('Wird angezeigt, wenn das Bild nicht geladen werden kann, und von Screenreadern vorgelesen.<br>Dient der Barrierefreiheit und Suchmaschinenoptimierung.');
    }
}
