<?php

declare(strict_types=1);

namespace Tricks\NovaTools\Nova\Fields;

use Laravel\Nova\Fields\Boolean;

final class Active extends Boolean
{
    public $helpText = 'Steuert die Sichtbarkeit des Eintrags auf der Website. Nur aktive Einträge werden angezeigt.';

    public function __construct(
        string $name = 'Aktiv',
        string $attribute = 'active'
    ) {
        parent::__construct($name, $attribute);
    }
}
