<?php

declare(strict_types=1);

namespace Tricks\NovaTools\Nova\Fields;

use Illuminate\Support\Carbon;

final class Date extends \Laravel\Nova\Fields\Date
{
    public $helpText = 'Steuert die Reihenfolge und das angezeigte Datum auf der Website. Hat keine technische Funktion für die Veröffentlichung.';

    public function __construct(
        string $name = 'Datum',
        string $attribute = 'date'
    ) {
        parent::__construct($name, $attribute);

        $this->defaultCallback = fn (): Carbon => Carbon::today();

        $this->rules = [
            'required',
            'date',
        ];
    }
}
